@@ -7,19 +7,64 @@ use Carp;
 
 use Search::Xapian::Enquire;
 
-require Exporter;
 require DynaLoader;
 
-our @ISA = qw(Exporter DynaLoader);
-# Items to export into caller's namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
+our @ISA = qw(DynaLoader);
 
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our @EXPORT_OK = ( );
+# In a new thread, copy objects of this class to unblessed, undef values.
+sub CLONE_SKIP { 1 }
 
-our @EXPORT = qw( );
+# Preloaded methods go here.
+
+use overload '='  => sub { $_[0]->clone() },
+             'fallback' => 1;
+
+sub enquire {
+  my $self = shift;
+  my $enquire = Search::Xapian::Enquire->new( $self );
+  if( @_ ) {
+    $enquire->set_query( @_ );
+  }
+  return $enquire;
+}
+
+
+sub clone() {
+  my $self = shift;
+  my $class = ref( $self );
+  my $copy = new2( $self );
+  bless $copy, $class;
+  return $copy;
+}
+
+sub new() {
+  my $class = shift;
+  my $database;
+  my $invalid_args;
+  if( scalar(@_) == 1 ) {
+    my $arg = shift;
+    my $arg_class = ref( $arg );
+    if( !$arg_class ) {
+      $database = new1( $arg );
+    } elsif( $arg_class eq $class ) {
+      $database = new2( $arg );
+    } else {
+      $invalid_args = 1;
+    }
+  } else {
+    $invalid_args = 1;
+  }
+  if( $invalid_args ) {
+    Carp::carp( "USAGE: $class->new(\$file), $class->new(\$database)" );
+    exit;
+  }
+  bless $database, $class;
+  return $database;
+}
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -32,7 +77,6 @@ L<Search::Xapian::WritableDatabase> for an object suitable for indexing.
 To perform searches, this class works with the L<Search::Xapian::Query>
 object.
 
-
 =head1 METHODS
 
 =over 4 
@@ -55,7 +99,7 @@ object.
 
 This re-opens the database(s) to the latest available version(s). It can be 
 used either to make sure the latest results are returned, or to recover from 
-a L<Xapian::DatabaseModifiedError>.
+a Xapian::DatabaseModifiedError.
 
 =item enquire [<query>]
 
@@ -143,56 +187,6 @@ Send a "keep-alive" to remote databases to stop them timing out.
 
 Get the number of elements indexed by a certain term.
 
-=cut
-
-# Preloaded methods go here.
-
-use overload '='  => sub { $_[0]->clone() },
-             'fallback' => 1;
-
-sub enquire {
-  my $self = shift;
-  my $enquire = Search::Xapian::Enquire->new( $self );
-  if( @_ ) {
-    $enquire->set_query( @_ );
-  }
-  return $enquire;
-}
-
-
-sub clone() {
-  my $self = shift;
-  my $class = ref( $self );
-  my $copy = new2( $self );
-  bless $copy, $class;
-  return $copy;
-}
-
-sub new() {
-  my $class = shift;
-  my $database;
-  my $invalid_args;
-  if( scalar(@_) == 1 ) {
-    my $arg = shift;
-    my $arg_class = ref( $arg );
-    if( !$arg_class ) {
-      $database = new1( $arg );
-    } elsif( $arg_class eq $class ) {
-      $database = new2( $arg );
-    } else {
-      $invalid_args = 1;
-    }
-  } else {
-    $invalid_args = 1;
-  }
-  if( $invalid_args ) {
-    Carp::carp( "USAGE: $class->new(\$file), $class->new(\$database)" );
-    exit;
-  }
-  bless $database, $class;
-  return $database;
-}
-
 =back
 
 =head1 SEE ALSO
@@ -200,5 +194,3 @@ sub new() {
 L<Search::Xapian>,L<Search::Xapian::Enquire>,L<Search::Xapian::WritableDatabase>
 
 =cut
-
-1;
