@@ -7,22 +7,15 @@ use Carp;
 
 use Search::Xapian::MSet::Tied;
 
-require Exporter;
 require DynaLoader;
 
-our @ISA = qw(Exporter DynaLoader);
-# Items to export into caller's namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our @EXPORT_OK = ( );
-
-our @EXPORT = qw( );
+our @ISA = qw(DynaLoader);
 
 # Preloaded methods go here.
 
+# In a new thread, copy objects of this class to unblessed, undef values.
+sub CLONE_SKIP { 1 }
+
 sub set_query {
   my $self = shift;
   my $query = shift;
@@ -100,6 +93,10 @@ sub get_matching_terms_end {
   exit;
 }
 
+1;
+
+__END__
+
 =head1 NAME
 
 Search::Xapian::Enquire - Make queries against a database
@@ -235,5 +232,3 @@ Returns a description of the object (for introspection).
 L<Search::Xapian::Query>, L<Search::Xapian::Database>
 
 =cut
-
-1;
